==> fonts-smc-chilanka_1.530.orig.tar.gz: chilanka-Version1.530/FONTLOG.md <==
# FONTLOG for Chilanka

This file provides detailed information on the Chilanka font software. This
information should be distributed along with the Chilanka fonts and any derivative
works.

## Basic Font Information

Chilanka is Malayalam handwriting style font designed by Santhosh Thottingal. Chilanka follows the common style one can see in everyday handwriting of Malayalam. It has a comprehensive Malayalam glyph set that contains most of the unique Malayalam conjuncts.

The glyph strokes are of uniform width with round ends giving the impression of written with either a thin felt-tip pen, or a ball-point pen. Sharp corners are completely avoided and gives the fine touch of beautiful curves of Malayalam script. The style is not the handwriting style of designer, but is based on many handwriting samples he observed. A uniform set was selected from them for the font. Even though the style is handwriting, the glyphs follow the horizontal baseline and can be used for body text too.

* Designer: Santhosh Thottingal
* Opentype Engineering: Santhosh Thottingal & Kavya Manohar

Chilanka belongs to the typefaces released by [Swathanthra Malayalam Computing](smc.org.in), a volunteer driven organization for developing and promoting free and opensource software for Malayalam computing. It shares the experience and expertise by the organization in its more than a decade effort in standardizing and improving opentype Malayalam typeface technology.

Chilanka inherits the traditional orthography style opentype font development practices pioneered by Rachana by K H Hussain and Rachana Aksharavedi. This includes glyph naming conventions, the supported ligature collection, a significant parts of opentype rules.

Chilanka development is currently hosted at:
http://gitlab.com/smc/fonts/chilanka

Released versions of this font is available at [smc.org.in/fonts](smc.org.in/fonts) for download. For old versions and detailed changelog, see https://gitlab.com/smc/fonts/chilanka/-/releases. Feature requests, bug reports and patches should be directed to our issue
tracker.

## Acknowledgements

(in alphabetical order)

* K H Hussain, Designer of Rachana font.
* Rajeesh K V, Opentype engineering.
* Swathanthra Malayalam computing and its volunteers for all help and support.

For a complete list of authors who contributed to the project, see CONTRIBUTORS.md

## Information for Contributors

Chilanka is released under the OFL 1.1 - https://scripts.sil.org/OFL For information on what you're allowed to change or modify, consult the LICENSE.txt. The [OFL-FAQ](https://scripts.sil.org/OFL-FAQ_web) also gives a very general rationale and various recommendations regarding why you would want to contribute to the project or make your own version of the font.

When you are submitting patches, please add your name to CONTRIBUTORS.md if you wish to be listed there.

See the project website for the current master and the various branches:
http://gitlab.com/smc/fonts/chilanka

==> fonts-smc-chilanka_1.540.orig.tar.gz: chilanka-Version1.540/FONTLOG.md <==
# FONTLOG for Chilanka

This file provides detailed information on the Chilanka font software. This
information should be distributed along with the Chilanka fonts and any derivative
works.

## Basic Font Information

Chilanka is Malayalam handwriting style font designed by Santhosh Thottingal. Chilanka follows the common style one can see in everyday handwriting of Malayalam. It has a comprehensive Malayalam glyph set that contains most of the unique Malayalam conjuncts.

The glyph strokes are of uniform width with round ends giving the impression of written with either a thin felt-tip pen, or a ball-point pen. Sharp corners are completely avoided and gives the fine touch of beautiful curves of Malayalam script. The style is not the handwriting style of designer, but is based on many handwriting samples he observed. A uniform set was selected from them for the font. Even though the style is handwriting, the glyphs follow the horizontal baseline and can be used for body text too.

* Designer: Santhosh Thottingal
* Opentype Engineering: Santhosh Thottingal & Kavya Manohar

Chilanka belongs to the typefaces released by [Swathanthra Malayalam Computing](smc.org.in), a volunteer driven organization for developing and promoting free and opensource software for Malayalam computing. It shares the experience and expertise by the organization in its more than a decade effort in standardizing and improving opentype Malayalam typeface technology.

Chilanka inherits the traditional orthography style opentype font development practices pioneered by Rachana by K H Hussain and Rachana Aksharavedi. This includes glyph naming conventions, the supported ligature collection, a significant parts of opentype rules.

Chilanka development is currently hosted at:
http://gitlab.com/smc/fonts/chilanka

Released versions of this font is available at [smc.org.in/fonts](smc.org.in/fonts) for download. For old versions and detailed changelog, see https://gitlab.com/smc/fonts/chilanka/-/releases. Feature requests, bug reports and patches should be directed to our issue
tracker.

## Acknowledgements

(in alphabetical order)

* K H Hussain, Designer of Rachana font.
* Rajeesh K V, Opentype engineering.
* Swathanthra Malayalam computing and its volunteers for all help and support.

For a complete list of authors who contributed to the project, see CONTRIBUTORS.md

## Information for Contributors

Chilanka is released under the OFL 1.1 - https://scripts.sil.org/OFL For information on what you're allowed to change or modify, consult the OFL.txt. The [OFL-FAQ](https://scripts.sil.org/OFL-FAQ_web) also gives a very general rationale and various recommendations regarding why you would want to contribute to the project or make your own version of the font.

When you are submitting patches, please add your name to CONTRIBUTORS.md if you wish to be listed there.

See the project website for the current master and the various branches:
http://gitlab.com/smc/fonts/chilanka
